==> ann-0.2.tar.gz: ann-0.2/lib/ann_ds_out.cpp <==
/***************************************************************************
                          ann_ds_out.cpp  -  description
                             -------------------
    begin                : pon kwi 14 2003
    copyright            : (C) 2003 by Bartosz Lis
    email                : bartoszl@ics.p.lodz.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <ann_ds_out.h>

  //                   //
 // class ANN::DS_out //
//                   //

ANN::DS_out::~DS_out()
{
}

bool
ANN::DS_out::do_reset()
{
  bool ret=(elem && ANN::DS_rec::do_reset());
  if (ret) elem->calc(orig->term(),out_data);
  return ret;
}

void
ANN::DS_out::do_next()
{
  if (elem)
  {
    ANN::DS_rec::do_next();
    elem->calc(orig->term(),out_data);
  }
}

bool
ANN::DS_out::do_seek(size_t term_)
{
  bool ret=(elem && ANN::DS_rec::do_seek(term_));
  if (ret) elem->calc(orig->term(),out_data);
  return ret;
}

const ANN::Size &
ANN::DS_out::get_sizes() const
{
  return out_data.get_sizes();
}

size_t
ANN::DS_out::get_size() const
{
  return out_data.get_size();
}

ANN::Term &
ANN::DS_out::term()
{
  return out_data;
}

const ANN::Term &
ANN::DS_out::term() const
{
  return out_data;
}

bool
ANN::DS_out::act_on(NE *elem_)
{
  if (elem_)
  {
    size_t l=elem_->get_in_size();
    if (!l || (l!=orig->get_size())) return false;
    out_data.resize(elem_->get_out_sizes());
  }
  else out_data.resize(0,0);
  elem=elem_;
  return true;
}

==> ann-0.3.tar.gz: ann-0.3/lib/ann_ds_out.cpp <==
/***************************************************************************
                          ann_ds_out.cpp  -  description
                             -------------------
    begin                : pon kwi 14 2003
    copyright            : (C) 2003 by Bartosz Lis
    email                : bartoszl@ics.p.lodz.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <ann_ds_out.h>

  //                   //
 // class ANN::DS_out //
//                   //

ANN::DS_out::~DS_out()
{
}

bool
ANN::DS_out::do_reset()
{
  bool ret=(elem && ANN::DS_rec::do_reset());
  if (ret) elem->calc(orig->term(),out_data);
  return ret;
}

void
ANN::DS_out::do_next()
{
  if (elem)
  {
    ANN::DS_rec::do_next();
    elem->calc(orig->term(),out_data);
  }
}

bool
ANN::DS_out::do_seek(size_t term_)
{
  bool ret=(elem && ANN::DS_rec::do_seek(term_));
  if (ret) elem->calc(orig->term(),out_data);
  return ret;
}

bool
ANN::DS_out::do_locate(const Loc &loc)
{
  bool ret=(elem && ANN::DS_rec::do_locate(loc));
  if (ret) elem->calc(orig->term(),out_data);
  return ret;
}

const ANN::Size &
ANN::DS_out::get_sizes() const
{
  return out_data.get_sizes();
}

size_t
ANN::DS_out::get_size() const
{
  return out_data.get_size();
}

ANN::Term &
ANN::DS_out::term()
{
  return out_data;
}

const ANN::Term &
ANN::DS_out::term() const
{
  return out_data;
}

bool
ANN::DS_out::act_on(NE *elem_)
{
  if (elem_)
  {
    size_t l=elem_->get_in_size();
    if (!l || (l!=orig->get_size())) return false;
    out_data.resize(elem_->get_out_sizes());
  }
  else out_data.resize(Size());
  elem=elem_;
  return true;
}
